//////////////////////////////////////////////////////////////////////////
//
// Conventions:
//
// +x = left
// +z = rear
// +y = up
// +pitch = nose up
// +yaw = nose right
// +roll = right
//
// [BODY]  - a rigid mass with mass and inertial properties
// [JOINT] - a ball joint constraining an offset of one body to an
//           offset of another body (eliminates 3 DOF)
// [HINGE] - a constraint restricting the relative rotations of two
//           bodies to be around a single axis (eliminates 2 DOF).
// [BAR]   - a constraint holding an offset of one body from an offset of
//           another body at a fixed distance (eliminates 1 DOF).
// [JOINT&HINGE] - both the joint and hinge constraints, forming the
//           conventional definition of a hinge (eliminates 5 DOF).
//
//////////////////////////////////////////////////////////////////////////

// Body including all rigidly attached parts (wings, barge boards, etc.)
[BODY]
name=body mass=(0.0) inertia=(0.0,0.0,0.0)
pos=(0.0,0.0,0.0) ori=(0.0,0.0,0.0)

// Front spindles
[BODY]
name=fl_spindle mass=(4.0) inertia=(0.0135,0.0130,0.0120)
pos=(0.725,0.0,-0.87) ori=(0.0,0.0,0.0)

[BODY]
name=fr_spindle mass=(4.0) inertia=(0.0135,0.0130,0.0120)
pos=(-0.725,0.0,-0.87) ori=(0.0,0.0,0.0)

// Front wheels
[BODY]
name=fl_wheel mass=(5.0) inertia=(0.235,0.165,0.165)
pos=(0.75,0.0,-0.87) ori=(0.0,0.0,0.0)

[BODY]
name=fr_wheel mass=(5.0) inertia=(0.235,0.165,0.165)
pos=(-0.75,0.0,-0.87) ori=(0.0,0.0,0.0)

// Rear spindles
[BODY]
name=rl_spindle mass=(4.0) inertia=(0.0135,0.0130,0.0120)
pos=(0.725,0.0,0.87) ori=(0.0,0.0,0.0)

[BODY]
name=rr_spindle mass=(4.0) inertia=(0.0135,0.0130,0.0120)
pos=(-0.725,0.0,0.87) ori=(0.0,0.0,0.0)

// Rear wheels (includes half of rear-axle)
[BODY]
name=rl_wheel mass=(5.0) inertia=(0.235,0.165,0.165)
pos=(0.75,0.0,0.87) ori=(0.0,0.0,0.0)

[BODY]
name=rr_wheel mass=(5.0) inertia=(0.235,0.165,0.165)
pos=(-0.75,0.0,0.87) ori=(0.0,0.0,0.0)

// Fuel in tank is not rigidly attached - it is attached with springs and
// dampers to simulate movement.  Properties are defined in the HDV file.
[BODY]
name=fuel_tank mass=(1.0) inertia=(1.0,1.0,1.0)
pos=(0.0,0.0,0.0) ori=(0.0,0.0,0.0)

// Driver's head is not rigidly attached, and it does NOT affect the vehicle
// physics.  Position is from the eyepoint defined in the VEH file, while
// other properties are defined in the head physics file.
[BODY]
name=driver_head mass=(5.0) inertia=(0.02,0.02,0.02)
pos=(0.0,0.0,0.0) ori=(0.0,0.0,0.0)

//////////////////////////////////////////////////////////////////////////
//
// Constraints
//
//////////////////////////////////////////////////////////////////////////

// Front wheel and spindle connections
[JOINT&HINGE]
posbody=fl_wheel negbody=fl_spindle pos=fl_wheel axis=(-0.78,0.0,0.0)

[JOINT&HINGE]
posbody=fr_wheel negbody=fr_spindle pos=fr_wheel axis=(0.78,0.0,0.0)


// Front left suspension (2 A-arms + 1 steering arm = 5 links)
[BAR] // forward upper arm
name=fl_fore_upper posbody=body negbody=fl_spindle pos=(0.151,0.0535,-0.977) neg=(0.668,0.0955,-0.861)

[BAR] // rearward upper arm
posbody=body negbody=fl_spindle pos=(0.151,0.0535,-0.727) neg=(0.668,0.0955,-0.861)

[BAR] // forward lower arm
posbody=body negbody=fl_spindle pos=(0.152,-0.055,-1.012) neg=(0.691,-0.0725,-0.876)

[BAR] // rearward lower arm
name=fl_fore_lower posbody=body negbody=fl_spindle pos=(0.152,-0.055,-0.727) neg=(0.691,-0.0725,-0.876)

[BAR] // steering arm (must be named for identification)
name=fl_steering posbody=body negbody=fl_spindle pos=(0.178,0.0525,-1.036) neg=(0.700,0.0975,-0.950)


// Front right suspension (2 A-arms + 1 steering arm = 5 links)
[BAR] // forward upper arm (used in steering lock calculation)
name=fr_fore_upper posbody=body negbody=fr_spindle pos=(-0.151,0.0535,-0.977) neg=(-0.668,0.0955,-0.861)

[BAR] // rearward upper arm
posbody=body negbody=fr_spindle pos=(-0.151,0.0535,-0.727) neg=(-0.668,0.0955,-0.861)

[BAR] // forward lower arm
name=fr_fore_lower posbody=body negbody=fr_spindle pos=(-0.152,-0.055,-1.012) neg=(-0.691,-0.0725,-0.876)

[BAR] // rearward lower arm
posbody=body negbody=fr_spindle pos=(-0.152,-0.055,-0.727) neg=(-0.691,-0.0725,-0.876)

[BAR] // steering arm (must be named for identification)
name=fr_steering posbody=body negbody=fr_spindle pos=(-0.178,0.0525,-1.036) neg=(-0.700,0.0975,-0.950)


// Rear left suspension (2 A-arms + 1 straight link = 5 links)
[BAR] // forward upper arm
posbody=body negbody=rl_spindle pos=(0.151,0.0535,0.763) neg=(0.668,0.0955,0.879)

[BAR] // rearward upper arm
posbody=body negbody=rl_spindle pos=(0.151,0.0535,1.013) neg=(0.668,0.0955,0.879)

[BAR] // forward lower arm
posbody=body negbody=rl_spindle pos=(0.152,-0.055,0.704) neg=(0.691,-0.0725,0.863)

[BAR] // rearward lower arm
posbody=body negbody=rl_spindle pos=(0.152,-0.055,1.013) neg=(0.691,-0.0725,0.863)

[BAR] // straight link
posbody=body negbody=rl_spindle pos=(0.151,0.0525,0.728) neg=(0.700,0.0975,0.790)


// Rear right suspension (2 A-arms + 1 straight link = 5 links)
[BAR] // forward upper arm
posbody=body negbody=rr_spindle pos=(-0.151,0.0535,0.763) neg=(-0.668,0.0955,0.879)

[BAR] // rearward upper arm
posbody=body negbody=rr_spindle pos=(-0.151,0.0535,1.013) neg=(-0.668,0.0955,0.879)

[BAR] // forward lower arm
posbody=body negbody=rr_spindle pos=(-0.152,-0.055,0.704) neg=(-0.691,-0.0725,0.863)

[BAR] // rearward lower arm
posbody=body negbody=rr_spindle pos=(-0.152,-0.055,1.013) neg=(-0.691,-0.0725,0.863)

[BAR] // straight link
posbody=body negbody=rr_spindle pos=(-0.151,0.0525,0.728) neg=(-0.700,0.0975,0.790)

// Rear spindle and wheel connections
[JOINT&HINGE]
posbody=rl_wheel negbody=rl_spindle pos=rl_wheel axis=(-0.78,0.0,0.0)

[JOINT&HINGE]
posbody=rr_wheel negbody=rr_spindle pos=rr_wheel axis=(0.78,0.0,0.0)


